@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.403';
+$VERSION = '3.418';
 
 ######################################################################
 #### Error Handling
@@ -38,6 +38,7 @@ sub new {
 		options => undef,	# Usually pointer to Verilog::Getopt
 		symbol_table => [],	# Symbol table for Verilog::Parser
  		preproc => 'Verilog::Preproc',
+		parser => 'Verilog::Netlist::File::Parser',
 		remove_defines_without_tick => 0,   # Overriden in SystemC::Netlist
 		#include_open_nonfatal => 0,
 		#keep_comments => 0,
@@ -517,6 +518,10 @@ used.
 An optional pointer to a Verilog::Getopt object, to be used for locating
 files.
 
+=item parser => $package_name
+
+The name of the parser class. Defaults to "Verilog::Netlist::File::Parser".
+
 =item preproc => $package_name
 
 The name of the preprocessor class. Defaults to "Verilog::Preproc".
@@ -687,7 +692,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2014 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2016 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
